@@ -104,6 +104,11 @@ fn non_debug_refs() {
 	assert!(let I(10) = & &I(10));
 }
 
+#[test]
+fn non_sized() {
+	assert!(b"hello"[..] == b"hello"[..]);
+}
+
 #[test]
 fn test_hygiene_bug() {
 	// Test to see if we work around a hygiene bug in the Rust compiler.
